/*
    "éparpillage" est un systeme de déploiment de pages de livres numériques dans l'espace
    Gepeto@du-libre.org licence artlibre (http://artlibre.org)
    V 6 au 16/6/2016
    https://snhack.org/doku.php?id=projets:eparpillage
    
  Base on FSWebServer - Example WebServer with SPIFFS backend for esp8266
  Copyright (c) 2015 Hristo Gochkov. All rights reserved.
  This file is part of the ESP8266WebServer library for Arduino environment.
  Add on with DNS lib captiv portal

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  upload the contents of the data folder with MkSPIFFS Tool ("ESP8266 Sketch Data Upload" in Tools menu in Arduino IDE)
  or you can upload the contents of a folder if you CD in that folder and run the following command:
  for file in `ls -A1`; do curl -F "file=@$PWD/$file" esp8266fs.local/edit; done

  access the sample web page at http://esp8266fs.local
  edit the page by going to http://esp8266fs.local/edit
*/
#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266HTTPClient.h>
#include <ESP8266WebServer.h>
//#include <ESP8266WiFiMulti.h>

#include <ESP8266mDNS.h>
#include "./DNSServer.h"                  // Patched lib
#include <FS.h>
#include <Ticker.h>

#define DBG_OUTPUT_PORT Serial
#define DEBUG

const byte BUFFER_SIZE = 60;

const byte DNS_PORT = 53;          // Capture DNS requests on port 53
/* Soft AP network parameters */
IPAddress apIP(192, 168, 4, 1);
IPAddress netMsk(255, 255, 255, 0);

DNSServer dnsServer;              // Create the DNS object
/** Should I connect to WLAN asap? */
boolean connect;
/** Last time I tried to connect to WLAN */
int essai_connexion = 0;
long lastConnectTry = 0;
/** Current WLAN status */
int status = WL_IDLE_STATUS;

char* nomssid = "LIVRE0"; // SSID pris par la page
char* passssid = "";
int param_version = 1;
int param_version_flash = 1;

char* ssid_biblio = "SNHACK";   // SSID ou chercher les pages
char* password_biblio = "1234567890";
String http_site = "http://192.168.1.10"; // site web ou trouver les pages
int http_port = 80;

const int TAILLE_NOM = 32;
const int NBR_FIC = 100; // on scanne  images max
int nbr_fic_image = 0 ; // dans le tableau
int nbr_fic = 0 ; //nbr de fichier de la flash
// tableau des fichiers dispo, idx,nom 8.3
char tabl_nom_fichier[NBR_FIC][TAILLE_NOM] = {
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123",
  "01234567.123"
};
String nom_extrait = "";
File param_fic;
Ticker flipper; // change index_htm
Ticker regarde; // test A0

// Global variables
WiFiClient client;
//ESP8266WiFiMulti WiFiMulti;

ESP8266WebServer server(80);
//holds the current upload
File fsUploadFile;
File list_file;
String responseHTML = ""
                      "<!DOCTYPE html><html><head><title>CaptivePortal</title></head><body>"
                      "<h1>Hello World!</h1><p>This is a captive portal example. All requests will "
                      "be redirected here.</p></body></html>";
//format bytes
String formatBytes(size_t bytes) {
  if (bytes < 1024) {
    return String(bytes) + "B";
  } else if (bytes < (1024 * 1024)) {
    return String(bytes / 1024.0) + "KB";
  } else if (bytes < (1024 * 1024 * 1024)) {
    return String(bytes / 1024.0 / 1024.0) + "MB";
  } else {
    return String(bytes / 1024.0 / 1024.0 / 1024.0) + "GB";
  }
}

String getContentType(String filename) {
  if (server.hasArg("download")) return "application / octet - stream";
  else if (filename.endsWith(".htm")) return "text / html";
  else if (filename.endsWith(".html")) return "text / html";
  else if (filename.endsWith(".cfg")) return "text / html";
  else if (filename.endsWith(".fic")) return "text / html";
  else if (filename.endsWith(".css")) return "text / css";
  else if (filename.endsWith(".js")) return "application / javascript";
  else if (filename.endsWith(".png")) return "image / png";
  else if (filename.endsWith(".gif")) return "image / gif";
  else if (filename.endsWith(".jpg")) return "image / jpeg";
  else if (filename.endsWith(".ico")) return "image / x - icon";
  else if (filename.endsWith(".xml")) return "text / xml";
  else if (filename.endsWith(".pdf")) return "application / x - pdf";
  else if (filename.endsWith(".zip")) return "application / x - zip";
  else if (filename.endsWith(".gz")) return "application / x - gzip";
  return "text / plain";
}

bool handleFileReadold(String path) {
  DBG_OUTPUT_PORT.println(path);
  if (path.endsWith("/")) path += "index.htm";

  server.sendHeader("Cache-Control", "no-cache, no-store, must-revalidate");
  server.sendHeader("Pragma", "no-cache");
  server.sendHeader("Expires", "-1");
  String contentType = getContentType(path);
  String pathWithGz = path + ".gz";
  if (SPIFFS.exists(pathWithGz) || SPIFFS.exists(path)) {
    if (SPIFFS.exists(pathWithGz)) path += ".gz";
    DBG_OUTPUT_PORT.println("handleFileRead: " + path);
    File file = SPIFFS.open(path, "r");
    size_t sent = server.streamFile(file, contentType);
    file.close();
    return true;
  } else {
    //server.send ( 200, "text/html", index_htm );
    DBG_OUTPUT_PORT.println("/index.htm");
    File file = SPIFFS.open("/index.htm", "r");
    size_t sent = server.streamFile(file, "text / html");
    file.close();
    return true;
  }
}

bool handleFileRead(String path) {
  DBG_OUTPUT_PORT.println("handleFileRead: " + path);
  if (path.endsWith("/")) path += "index.htm";
  String contentType = getContentType(path);
  String pathWithGz = path + ".gz";
  if (SPIFFS.exists(pathWithGz) || SPIFFS.exists(path)) {
    if (SPIFFS.exists(pathWithGz))
      path += ".gz";
    DBG_OUTPUT_PORT.println("ouvre " + path);

    File file = SPIFFS.open(path, "r");
    server.sendHeader("Cache-Control", "no-cache, no-store, must-revalidate");
    server.sendHeader("Pragma", "no-cache");
    server.sendHeader("Expires", "-1");
    size_t sent = server.streamFile(file, contentType);
    file.close();
    return true;
  }
  File file = SPIFFS.open("/index.htm", "r");
  DBG_OUTPUT_PORT.println("ouvre index.htm");

  server.sendHeader("Cache-Control", "no-cache, no-store, must-revalidate");
  server.sendHeader("Pragma", "no-cache");
  server.sendHeader("Expires", "-1");
  size_t sent = server.streamFile(file, contentType);
  file.close();
  //server.send(200, "text / plain", index_htm);
  return true;
}
void handleFileUpload() {
  if (server.uri() != " / edit") return;
  HTTPUpload& upload = server.upload();
  if (upload.status == UPLOAD_FILE_START) {
    String filename = upload.filename;
    if (!filename.startsWith(" / ")) filename = " / " + filename;
    DBG_OUTPUT_PORT.print("handleFileUpload Name: ");
    DBG_OUTPUT_PORT.println(filename);
    fsUploadFile = SPIFFS.open(filename, "w");
    filename = String();
  } else if (upload.status == UPLOAD_FILE_WRITE) {
    //DBG_OUTPUT_PORT.print("handleFileUpload Data: "); DBG_OUTPUT_PORT.println(upload.currentSize);
    if (fsUploadFile)
      fsUploadFile.write(upload.buf, upload.currentSize);
  } else if (upload.status == UPLOAD_FILE_END) {
    if (fsUploadFile)
      fsUploadFile.close();
    DBG_OUTPUT_PORT.print("handleFileUpload Size: "); DBG_OUTPUT_PORT.println(upload.totalSize);
  }
}

void handleFileDelete() {
  if (server.args() == 0) return server.send(500, "text / plain", "BAD ARGS");
  String path = server.arg(0);
  DBG_OUTPUT_PORT.println("handleFileDelete: " + path);
  if (path == " / ")
    return server.send(500, "text / plain", "BAD PATH");
  if (!SPIFFS.exists(path))
    return server.send(404, "text / plain", "FileNotFound");
  SPIFFS.remove(path);
  server.send(200, "text / plain", "");
  path = String();
}

void handleFileCreate() {
  if (server.args() == 0)
    return server.send(500, "text / plain", "BAD ARGS");
  String path = server.arg(0);
  DBG_OUTPUT_PORT.println("handleFileCreate: " + path);
  if (path == " / ")
    return server.send(500, "text / plain", "BAD PATH");
  if (SPIFFS.exists(path))
    return server.send(500, "text / plain", "FILE EXISTS");
  File file = SPIFFS.open(path, "w");
  if (file)
    file.close();
  else
    return server.send(500, "text / plain", "CREATE FAILED");
  server.send(200, "text / plain", "");
  path = String();
}

void handleFileList() {
  if (!server.hasArg("dir")) {
    server.send(500, "text / plain", "BAD ARGS");
    return;
  }

  String path = server.arg("dir");
  DBG_OUTPUT_PORT.println("handleFileList: " + path);
  Dir dir = SPIFFS.openDir(path);
  path = String();

  String output = "[";
  while (dir.next()) {
    File entry = dir.openFile("r");
    if (output != "[") output += ',';
    bool isDir = false;
    output += " {\"type\":\"";
    output += (isDir) ? "dir" : "file";
    output += "\",\"name\":\"";
    output += String(entry.name()).substring(1);
    output += "\"}";
    entry.close();
  }

  output += "]";
  server.send(200, "text/json", output);
}
int Recup_Pages(String page) {
  Serial.println("page :");
  Serial.println(page);

  String url = http_site +  "/" + ESP.getChipId() + "/" + page;
  DBG_OUTPUT_PORT.println(url);
  HTTPClient http;
  http.begin(url);
  //http.begin("http://192.168.1.10/16281490.htm") ;
  //http.begin("http://192.168.1.10/index.html") ;
  //http.begin("http://192.168.1.10/16281490/list.fic") ;

  int httpCode = http.GET();
  if (httpCode > 0) {
    //fichiers et serveur trouvés
    // HTTP header has been send and Server response header has been handled
    DBG_OUTPUT_PORT.printf("[HTTP] GET... code: %d\n", httpCode);
    if (httpCode == HTTP_CODE_OK) {
      // get lenght of document (is -1 when Server sends no Content-Length header)
      int len = http.getSize();
      // create buffer for read
      uint8_t buff[128] = { 0 };
      // get tcp stream
      fsUploadFile = SPIFFS.open(page, "w");
      WiFiClient * stream = http.getStreamPtr();
      // read all data from server
      while (http.connected() && (len > 0 || len == -1)) {
        // get available data size
        size_t size = stream->available();
        if (size) {
          // read up to 128 byte
          int c = stream->readBytes(buff, ((size > sizeof(buff)) ? sizeof(buff) : size));
          //DBG_OUTPUT_PORT.write(buff, c);
          fsUploadFile.write(buff, c);
          if (len > 0) {
            len -= c;
          }
        }
        delay(1);
      }
      //DBG_OUTPUT_PORT.println();
      fsUploadFile.flush();
      fsUploadFile.close();
      delay(200);
      if (SPIFFS.exists(page)) {
        fsUploadFile = SPIFFS.open(page, "r");
        DBG_OUTPUT_PORT.print(page);
        DBG_OUTPUT_PORT.print(" fait ");
        DBG_OUTPUT_PORT.println(fsUploadFile.size());
        fsUploadFile.close();
      }
      DBG_OUTPUT_PORT.print("[HTTP] connection closed or file end.\n");
      http.end();
      return 0;
    }
  } else {
    DBG_OUTPUT_PORT.printf("[HTTP] GET... failed, error: %s\n", http.errorToString(httpCode).c_str());
    http.end();
    return 1;
  }
  http.end();
  return 1;
}
void parametres() { // remseigne nomssid passssid et param_version du fichier /param.cfg
  int i , buffer_lenght, line_counter ;
  char buffer[80], *key, *value;
  param_fic = SPIFFS.open("/param.cfg", "r");
  if (param_fic) {
    while (param_fic.available() > 0 ) {

      i = 0;
      while ((buffer[i++] = param_fic.read()) != '\n') {
        /* Si la ligne dépasse la taille du buffer */
        if (i == BUFFER_SIZE) {
          /* On finit de lire la ligne mais sans stocker les données */
          while (param_fic.read() != '\n');
          break; // Et on arrête la lecture de cette ligne
        }
      }
      buffer_lenght = i;
      /* Gestion des lignes trop grande */
      if (i == BUFFER_SIZE) {
        DBG_OUTPUT_PORT.println("Ligne trop longue à la ligne ");
        DBG_OUTPUT_PORT.println(line_counter, DEC);
        DBG_OUTPUT_PORT.println(i);
      }
      /* Finalise la chaine de caractéres ASCIIZ en supprimant le \n au passage */
      buffer[--i] = '\0';
      /* Incrémente le compteur de lignes */
      ++line_counter;
      /* Ignore les lignes vides ou les lignes de commentaires */
      if (buffer[0] == '\0' || buffer[0] == '#') continue;
      /* Cherche l'emplacement de la clef en ignorant les espaces et les tabulations en début de ligne */
      i = 0;
      while (buffer[i] == ' ' || buffer[i] == '\t') {
        if (++i == buffer_lenght) break; // Ignore les lignes contenant uniquement des espaces et/ou des tabulations
      }
      if (i == buffer_lenght) continue; // Gère les lignes contenant uniquement des espaces et/ou des tabulations
      key = &buffer[i];
      /* Cherche l'emplacement du séparateur = en ignorant les espaces et les tabulations âpres la clef */
      while (buffer[i] != '=') {
        /* Ignore les espaces et les tabulations */
        if (buffer[i] == ' ' || buffer[i] == '\t') buffer[i] = '\0';
        if (++i == buffer_lenght) {
          DBG_OUTPUT_PORT.println("Ligne mal forme a la ligne ");
          DBG_OUTPUT_PORT.println(line_counter, DEC);
          break; // Ignore les lignes mal formé
        }
      }
      if (i == buffer_lenght) continue; // Gère les lignes mal formé
      /* Transforme le séparateur = en \0 et continue */
      buffer[i++] = '\0';
      /* Cherche l'emplacement de la valeur en ignorant les espaces et les tabulations âpres le séparateur */
      while (buffer[i] == ' ' || buffer[i] == '\t') {
        if (++i == buffer_lenght) {
          DBG_OUTPUT_PORT.println("Ligne mal forme a la ligne ");
          DBG_OUTPUT_PORT.println(line_counter, DEC);
          break; // Ignore les lignes mal formé
        }
      }
      if (i == buffer_lenght) continue; // Gère les lignes mal formé
      value = &buffer[i];
      DBG_OUTPUT_PORT.print(key);
      DBG_OUTPUT_PORT.print(" : ");
      DBG_OUTPUT_PORT.println(value);

      /* Transforme les données texte en valeur utilisable */
      if (strcmp(key, "SSID") == 0) {
        sprintf(nomssid, "%s", value);
        DBG_OUTPUT_PORT.print("ssid ");
        DBG_OUTPUT_PORT.println(nomssid);
      }
      else if (strcmp(key, "PASSWORD") == 0) {
        sprintf(passssid, "%s", value);
        DBG_OUTPUT_PORT.print("password ");
        DBG_OUTPUT_PORT.println(passssid);
      }
      else if (strcmp(key, "VERSION") == 0) {
        param_version = atoi(value);
        DBG_OUTPUT_PORT.println(param_version);
      }
      else if (strcmp(key, "BIBLIOSSID") == 0) {
        sprintf(ssid_biblio, "%s", value);
        DBG_OUTPUT_PORT.print("ssid_biblio ");
        DBG_OUTPUT_PORT.println(ssid_biblio);
      }
      else if (strcmp(key, "BIBLIOPASSWORD") == 0) {
        sprintf(password_biblio, "%s", value);
        DBG_OUTPUT_PORT.print("password_biblio ");
        DBG_OUTPUT_PORT.println(password_biblio);
      }
      else if (strcmp(key, "BIBLIOSITE") == 0) {
        //sprintf(http_site, "%s", value);
        http_site = value;
        DBG_OUTPUT_PORT.print("http_site ");
        DBG_OUTPUT_PORT.println(http_site);
      }

      else { // Default
        DBG_OUTPUT_PORT.print("Clef inconnu ");
        DBG_OUTPUT_PORT.println(key);
      }
      key = "";
      value = "";
    }
    /* Ferme le fichier de configuration */
    param_fic.close();
  } else {
    DBG_OUTPUT_PORT.println("pb fichier ouverture /param.cfg");
  }
}
void Mise_a_jour() { // format et mise a jour de la flash
  DBG_OUTPUT_PORT.println("version differente, format flash et rerecupere les fichiers de la  liste ");
  SPIFFS.end();
  DBG_OUTPUT_PORT.print(SPIFFS.format());// supprme tous les fichiers de la flash
  SPIFFS.begin();
  DBG_OUTPUT_PORT.println("formatee");
  // re recupere fichier de parametres
  for (int i = 0; i < 5; i++) {
    essai_connexion = Recup_Pages("param.cfg");
    if (essai_connexion == 0 ) break;
    delay(2000);
  }
  delay(1000);
  // recupere liste des fichiers a recuperer
  for (int i = 0; i < 5; i++) {
    essai_connexion = Recup_Pages("list.fic");
    if (essai_connexion == 0 ) break;
    delay(2000);
  }
  delay(1000);
  list_file = SPIFFS.open("list.fic", "r");
  if (list_file) {
    while (list_file.available() > 0 ) { // nbr_fic de ligne de list_file
      int j = 0;
      while ((tabl_nom_fichier[nbr_fic][j] = list_file.read()) != '\n') {
        j++;
      }
      tabl_nom_fichier[nbr_fic][j] = '\0';
      DBG_OUTPUT_PORT.print("fichier :");
      DBG_OUTPUT_PORT.println(tabl_nom_fichier[nbr_fic]);
      nbr_fic++;
    }
    for (int i = 0; i <= nbr_fic; i++) {
      int l = strlen(tabl_nom_fichier[i]);
      DBG_OUTPUT_PORT.print(tabl_nom_fichier[i]);
      DBG_OUTPUT_PORT.print(" -> ");
      DBG_OUTPUT_PORT.println(l);
      if (strncmp(tabl_nom_fichier[i], "list.fic", 8)  != 0 && l > 3 ) Recup_Pages(tabl_nom_fichier[i]); // recupere et flash les fichiers
    }
    list_file.close();
  } else {
    DBG_OUTPUT_PORT.println("pb ouverture /list.fic");
  }
}
void setup(void) {
  //init tableau des fichiers
  for ( int i = 0; i < NBR_FIC; i++) {
    for (int j = 0; j < 13; j++) tabl_nom_fichier[i][j] = '\0';
  }
  DBG_OUTPUT_PORT.begin(115200);
  DBG_OUTPUT_PORT.print("\n");
  DBG_OUTPUT_PORT.setDebugOutput(true);
  DBG_OUTPUT_PORT.println(ESP.getChipId());
  SPIFFS.begin();
  Serial.println("dir flash");
  Dir dir = SPIFFS.openDir("/");
  char str[14] = "";
  while (dir.next()) {
    String fileName = dir.fileName();
    size_t fileSize = dir.fileSize();
    DBG_OUTPUT_PORT.printf("FS File: %s, size: %s\n", fileName.c_str(), formatBytes(fileSize).c_str());
  }
  DBG_OUTPUT_PORT.printf("\n");

  parametres(); // recupere ssid,pass,param_version sur la flash
  param_version_flash = param_version ;

  //WIFI connexion aux pages sources
  Serial.print("Connexion aux sources...");
  //WiFi.mode(WIFI_STA);
  WiFi.begin(ssid_biblio, password_biblio);
  //WiFiMulti.addAP(ssid_biblio, password_biblio);
  while ( WiFi.status() != WL_CONNECTED ) {
    Serial.print(".");
    if (essai_connexion++ >= 10) break; // on sort au bout de 10 s
    delay(1000);
  }
  if (WiFi.status() == WL_CONNECTED ) { // si on se connecte on verifi les fichiers
    essai_connexion = 0;
    for (int i = 0; i < 5; i++) {
      Serial.print("recupere le fichier parametres ");
      essai_connexion = Recup_Pages("/param.cfg");
      Serial.print(essai_connexion);
      if (essai_connexion == 0 ) break;
      delay(2000);
    }
    Serial.println("");
    delay (200);
    if (essai_connexion == 0) {
      Serial.println("param ok");
      param_fic = SPIFFS.open("/param.cfg", "r");
      if (param_fic) {
        parametres();
        if (param_version_flash != param_version) Mise_a_jour();
      }
    }

    //WIFI INIT
    WiFi.disconnect();
  }
  Serial.println("dir flash");
  Dir dir2 = SPIFFS.openDir("/");
  while (dir2.next()) {
    String fileName = dir2.fileName();
    size_t fileSize = dir2.fileSize();
    DBG_OUTPUT_PORT.printf("FS File: %s, size: %s\n", fileName.c_str(), formatBytes(fileSize).c_str());
  }
  DBG_OUTPUT_PORT.printf("\n");
  Serial.print("Configuring access point...");
  WiFi.softAPConfig(apIP, apIP, netMsk);
  delay(500);
  WiFi.disconnect();
  if (strlen(passssid) == 0) {
    WiFi.softAP(nomssid);
    delay(500);
    DBG_OUTPUT_PORT.print("ouverture de ");
    DBG_OUTPUT_PORT.println(nomssid);
  } else {
    WiFi.softAP(nomssid, passssid);
    delay(500);
    DBG_OUTPUT_PORT.print("ouverture  et paswd de ");
    DBG_OUTPUT_PORT.print(nomssid);
    DBG_OUTPUT_PORT.print(" ");
    DBG_OUTPUT_PORT.println(passssid);
  }
  delay(100);
  // Setup the DNS server redirecting all the domains to the apIP
  dnsServer.setErrorReplyCode(DNSReplyCode::NoError);
  dnsServer.start(DNS_PORT, "*", apIP);
  Serial.print("AP IP address: ");
  Serial.println(WiFi.softAPIP());
  delay(2000);

  DBG_OUTPUT_PORT.println("");
  delay(100);
  //SERVER INIT
  /*

    //list directory
    server.on("/list", HTTP_GET, handleFileList);
    //load editor
    server.on("/edit", HTTP_GET, []() {
    if (!handleFileRead("/edit.htm")) server.send(404, "text/plain", "FileNotFound");
    });
    //create file
    server.on("/edit", HTTP_PUT, handleFileCreate);
    //delete file
    server.on("/edit", HTTP_DELETE, handleFileDelete);
    //first callback is called after the request has ended with all parsed arguments
    //second callback handles file uploads at that location
    server.on("/edit", HTTP_POST, []() {
    server.send(200, "text/plain", "");
    }, handleFileUpload);
  */
  //called when the url is not defined here
  //use it to load content from SPIFFS
  server.onNotFound([]() {
    if (!handleFileRead(server.uri()))
      server.send(404, "text/plain", "FileNotFound");
  });

  //get heap status, analog input value and all GPIO statuses in one json call
  server.on("/all", HTTP_GET, []() {
    String json = "{";
    json += "\"heap\":" + String(ESP.getFreeHeap());
    json += ", \"analog\":" + String(analogRead(A0));
    json += ", \"gpio\":" + String((uint32_t)(((GPI | GPO) & 0xFFFF) | ((GP16I & 0x01) << 16)));
    json += "}";
    server.send(200, "text/json", json);
    json = String();
  });

  server.begin();
  DBG_OUTPUT_PORT.println("HTTP server started");
  //regarde.attach(10, changement ); // toutes les 10s on scanne A0
  //flipper.attach(600, suivant ); // toutes les 10m on reboot

}
/*

  void suivant() {
  ESP.restart();
  }
  void changement() {
  int val = analogRead(A0) / 4;
  if (val > 2) {
    DBG_OUTPUT_PORT.println(val);
    suivant();
  }
  }
*/

void loop(void) {
  server.handleClient();
  dnsServer.processNextRequest();
}
